@@ -1,5 +1,6 @@
 #pragma once
 #include <string>
+#include <vector>
 #include "iterators_b3s23.h"
 namespace apg {
 
@@ -18,6 +19,12 @@ namespace apg {
         return -1;
     }
 
+    std::vector<std::string> get_all_rules() {
+        std::vector<std::string> x;
+        x.emplace_back("b3s23");
+        return x;
+    }
+
     int uli_get_family(int rule) {
         switch (rule) {
             case 0 : return 0;
