@@ -2,7 +2,11 @@ import os
 import re
 
 from collections import defaultdict
-from collections.abc import Sequence
+
+try:
+    from collections.abc import Sequence
+except ImportError:
+    from collections import Sequence
 
 catagolue_url = "https://catagolue.hatsya.com"
 
