@@ -276,6 +276,20 @@ b3o$25bo6bobo2b2o$13bobo7bob2o$12b2ob2o6bobo$13bob2o6b2o$2bo14bo$bobo12bo$2ob
 
         self.assertEqual(np.all(values == values2), True)
 
+        mat2pat = lambda M : self.lt.pattern('$'.join([''.join(['bo'[y] for y in x]) for x in M.tolist()]) + '!')
+
+        A = np.array(np.random.uniform(0, 2, size=(34, 55)), dtype='uint64')
+        B = np.array(np.random.uniform(0, 2, size=(55, 89)), dtype='uint64')
+        C = np.dot(A, B) % 2
+
+        pA = mat2pat(A)
+        pB = mat2pat(B)
+        pC = mat2pat(C)
+
+        pAB = pA.__matmul__(pB)
+
+        self.assertEqual(pC, pAB)
+
     def test_mutable(self):
 
         lidka = self.lt.pattern("bo$obo$bo8$8bo$6bobo$5b2obo2$4b3o!", 'b3s23')
